#!/bin/sh
# Copyright 2005-2014 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
#
# In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
# virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.

. ./include.sh

#
# Check program completed successfully. We have to resort to testing
# the output as there is no way in Fortran to set the exit code
#
${examples_dir}f_read_from_file | grep 'Passed' >/dev/null
